@@ -58,6 +58,7 @@ def parse_config():
         # else:
             # print(f"Config file not found in {cfg_file} directory.")
             # print(f"Checking next directory...")
+    # if found config file logger which one was found and path
     if not config:
         admin_interface = "https://software-api-admin.robinradar.systems"
         doc_pages = "https://robinradar.atlassian.net/wiki/spaces/DEV/pages/284033095/Software+Deployment+API"
@@ -67,7 +68,7 @@ def parse_config():
         sys.exit(0)
 
     check_and_ask(config)
-
+    print(f"Config {file} found at full path {os.path.abspath(file)}")
     # write the config file with the new values
     try:
         with open(file, "w") as config_file:
